@@ -25,6 +25,7 @@ import (
 	"strings"
 	"time"
 
+	"k8s.io/client-go/kubernetes"
 	"k8s.io/kops/pkg/commands/commandutils"
 	"k8s.io/kops/upup/pkg/fi/cloudup"
 	"k8s.io/kubectl/pkg/util/i18n"
@@ -33,8 +34,6 @@ import (
 	"github.com/spf13/cobra"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/client-go/kubernetes"
-	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/cmd/kops/util"
 	kopsapi "k8s.io/kops/pkg/apis/kops"
@@ -148,27 +147,24 @@ func RunValidateCluster(ctx context.Context, f *util.Factory, out io.Writer, opt
 		return nil, fmt.Errorf("no InstanceGroup objects found")
 	}
 
-	// TODO: Refactor into util.Factory
-	contextName := cluster.ObjectMeta.Name
-	configLoadingRules := clientcmd.NewDefaultClientConfigLoadingRules()
-	if options.kubeconfig != "" {
-		configLoadingRules.ExplicitPath = options.kubeconfig
-	}
-	config, err := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(
-		configLoadingRules,
-		&clientcmd.ConfigOverrides{CurrentContext: contextName}).ClientConfig()
+	restConfig, err := f.RESTConfig(cluster)
 	if err != nil {
-		return nil, fmt.Errorf("cannot load kubecfg settings for %q: %v", contextName, err)
+		return nil, fmt.Errorf("getting rest config: %w", err)
 	}
 
-	k8sClient, err := kubernetes.NewForConfig(config)
+	httpClient, err := f.HTTPClient(cluster)
 	if err != nil {
-		return nil, fmt.Errorf("cannot build kubernetes api client for %q: %v", contextName, err)
+		return nil, fmt.Errorf("getting http client: %w", err)
+	}
+
+	k8sClient, err := kubernetes.NewForConfigAndClient(restConfig, httpClient)
+	if err != nil {
+		return nil, fmt.Errorf("building kubernetes client: %w", err)
 	}
 
 	timeout := time.Now().Add(options.wait)
 
-	validator, err := validation.NewClusterValidator(cluster, cloud, list, config.Host, k8sClient)
+	validator, err := validation.NewClusterValidator(cluster, cloud, list, restConfig, k8sClient)
 	if err != nil {
 		return nil, fmt.Errorf("unexpected error creating validatior: %v", err)
 	}
