@@ -17,6 +17,7 @@ limitations under the License.
 package v1alpha2
 
 import (
+	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -555,6 +556,11 @@ type KubeAPIServerConfig struct {
 	DefaultNotReadyTolerationSeconds *int64 `json:"defaultNotReadyTolerationSeconds,omitempty" flag:"default-not-ready-toleration-seconds"`
 	// DefaultUnreachableTolerationSeconds
 	DefaultUnreachableTolerationSeconds *int64 `json:"defaultUnreachableTolerationSeconds,omitempty" flag:"default-unreachable-toleration-seconds"`
+
+	// Env allows users to pass in env variables to the apiserver container.
+	// This can be useful to control some environment runtime settings, such as GOMEMLIMIT and GOCG to tweak the memory settings of the apiserver
+	// This also allows the flexibility for adding any other variables for future use cases
+	Env []corev1.EnvVar `json:"env,omitempty"`
 }
 
 // KubeControllerManagerConfig is the configuration for the controller
@@ -954,6 +960,9 @@ type CloudConfiguration struct {
 	// GCEServiceAccount specifies the service account with which the GCE VM runs
 	// +k8s:conversion-gen=false
 	GCEServiceAccount string `json:"gceServiceAccount,omitempty"`
+	// GCEUseStartupScript specifies enables using startup-script instead of user-data metadata.
+	// +k8s:conversion-gen=false
+	GCEUseStartupScript *bool `json:"gceUseStartupScript,omitempty"`
 	// DisableSecurityGroupIngress disables the Cloud Controller Manager's creation
 	// of an AWS Security Group for each load balancer provisioned for a Service (AWS only).
 	// +k8s:conversion-gen=false
