@@ -27,12 +27,12 @@ type GCPCloudControllerManagerOptionsBuilder struct {
 	*OptionsContext
 }
 
-var _ loader.OptionsBuilder = (*GCPCloudControllerManagerOptionsBuilder)(nil)
+var _ loader.ClusterOptionsBuilder = (*GCPCloudControllerManagerOptionsBuilder)(nil)
 
-func (b *GCPCloudControllerManagerOptionsBuilder) BuildOptions(options interface{}) error {
-	clusterSpec := options.(*kops.ClusterSpec)
+func (b *GCPCloudControllerManagerOptionsBuilder) BuildOptions(cluster *kops.Cluster) error {
+	clusterSpec := &cluster.Spec
 
-	if clusterSpec.GetCloudProvider() != kops.CloudProviderGCE {
+	if cluster.GetCloudProvider() != kops.CloudProviderGCE {
 		return nil
 	}
 
@@ -73,13 +73,13 @@ func (b *GCPCloudControllerManagerOptionsBuilder) BuildOptions(options interface
 
 	if ccmConfig.Image == "" {
 		// TODO: Implement CCM image publishing
-		switch b.KubernetesVersion.Minor {
+		switch b.ControlPlaneKubernetesVersion().Minor() {
 		default:
 			ccmConfig.Image = "gcr.io/k8s-staging-cloud-provider-gcp/cloud-controller-manager:master"
 		}
 	}
 
-	if b.IsKubernetesLT("1.25") {
+	if b.ControlPlaneKubernetesVersion().IsLT("1.25") {
 		ccmConfig.EnableLeaderMigration = fi.PtrTo(true)
 	}
 
