@@ -75,14 +75,24 @@ func (t *Tester) setSkipRegexFlag() error {
 		skipRegex += "|TCP.CLOSE_WAIT"
 		// https://github.com/cilium/cilium/issues/15361
 		skipRegex += "|external.IP.is.not.assigned.to.a.node"
-		// https://github.com/cilium/cilium/issues/14287
-		skipRegex += "|same.port.number.but.different.protocols"
-		skipRegex += "|same.hostPort.but.different.hostIP.and.protocol"
-		// https://github.com/cilium/cilium/issues/9207
-		skipRegex += "|serve.endpoints.on.same.port.and.different.protocols"
+
+		if networking.Cilium.Version < "v1.17" {
+			// https://github.com/cilium/cilium/issues/14287
+			skipRegex += "|same.port.number.but.different.protocols"
+			skipRegex += "|same.hostPort.but.different.hostIP.and.protocol"
+			// https://github.com/cilium/cilium/issues/9207
+			skipRegex += "|serve.endpoints.on.same.port.and.different.protocols"
+		}
+
 		// https://github.com/kubernetes/kubernetes/blob/418ae605ec1b788d43bff7ac44af66d8b669b833/test/e2e/network/networking.go#L135
 		skipRegex += "|should.check.kube-proxy.urls"
 
+		if k8sVersion.Minor < 33 {
+			// This seems to be specific to the kube-proxy replacement
+			// < 33 so we look at this again
+			skipRegex += "|Services.should.support.externalTrafficPolicy.Local.for.type.NodePort"
+		}
+
 		if isPre28 {
 			// These may be fixed in Cilium 1.13 but skipping for now
 			skipRegex += "|Service.with.multiple.ports.specified.in.multiple.EndpointSlices"
@@ -97,6 +107,14 @@ func (t *Tester) setSkipRegexFlag() error {
 			// Ref: https://github.com/kubernetes/kubernetes/pull/113335
 			skipRegex += "|should.create.a.Pod.with.SCTP.HostPort"
 		}
+
+		if k8sVersion.Minor < 34 {
+			// < 34 so we revisit this in future
+			// This test checks for kube-proxy on port 10249 (`127.0.0.1:10249/proxyMode`)
+			// It appears that the cilium kube-proxy replacement does not implement this.
+			// Ref: https://github.com/kubernetes/kubernetes/issues/126903
+			skipRegex += "|KubeProxy.should.update.metric.for.tracking.accepted.packets.destined.for.localhost.nodeports"
+		}
 	} else if networking.KubeRouter != nil {
 		skipRegex += "|should set TCP CLOSE_WAIT timeout|should check kube-proxy urls"
 	} else if networking.Kubenet != nil {
@@ -104,8 +122,7 @@ func (t *Tester) setSkipRegexFlag() error {
 	}
 
 	if cluster.Spec.LegacyCloudProvider == "digitalocean" {
-		// https://github.com/kubernetes/kubernetes/issues/121018
-		skipRegex += "|Services.should.respect.internalTrafficPolicy=Local.Pod.and.Node,.to.Pod|Services.should.function.for.service.endpoints.using.hostNetwork"
+		skipRegex += "|Services.should.respect.internalTrafficPolicy=Local.Pod.and.Node,.to.Pod"
 	}
 
 	if cluster.Spec.LegacyCloudProvider == "gce" {
@@ -120,15 +137,20 @@ func (t *Tester) setSkipRegexFlag() error {
 		skipRegex += "|should.be.mountable.when.non-attachable"
 		// The in-tree driver and its E2E tests use `topology.kubernetes.io/zone` but the CSI driver uses `topology.gke.io/zone`
 		skipRegex += "|In-tree.Volumes.\\[Driver:.gcepd\\].*topology.should.provision.a.volume.and.schedule.a.pod.with.AllowedTopologies"
-	}
 
-	if cluster.Spec.LegacyCloudProvider == "gce" {
 		// this tests assumes a custom config for containerd:
 		// https://github.com/kubernetes/test-infra/blob/578d86a7be187214be6ccd60e6ea7317b51aeb15/jobs/e2e_node/containerd/config.toml#L19-L21
 		// ref: https://github.com/kubernetes/kubernetes/pull/104803
 		skipRegex += "|RuntimeClass.should.run"
 		// https://github.com/kubernetes/kubernetes/pull/108694
 		skipRegex += "|Metadata.Concealment"
+
+		if k8sVersion.Minor >= 31 {
+			// Most e2e framework code for the in-tree provider has been removed but some test cases remain
+			// https://github.com/kubernetes/kubernetes/pull/124519
+			// https://github.com/kubernetes/test-infra/pull/33222
+			skipRegex += "\\[sig-cloud-provider-gcp\\]"
+		}
 	}
 
 	if k8sVersion.Minor >= 22 {
@@ -140,10 +162,26 @@ func (t *Tester) setSkipRegexFlag() error {
 	}
 
 	if cluster.Spec.LegacyCloudProvider == "aws" {
-		// This test fails on RHEL-based distros because they return fully qualified hostnames yet the k8s node names are not fully qualified.
-		// Dedicated job testing this: https://testgrid.k8s.io/kops-misc#kops-aws-k28-hostname-bug123255
-		// ref: https://github.com/kubernetes/kops/issues/16349
-		// ref: https://github.com/kubernetes/kubernetes/issues/123255
+		if k8sVersion.Minor <= 26 {
+			// Prow jobs are being migrated to community-owned EKS clusters.
+			// The e2e.test binaries from older k/k builds dont have new enough aws-sdk-go versions to authenticate from EKS pods.
+			// This disables tests that depend on e2e.test's aws-sdk-go.
+			//
+			// > Couldn't create a new PD in zone "ap-northeast-1c", sleeping 5 seconds: NoCredentialProviders: no valid providers in chain. Deprecated.
+			//
+			// We can remove this once we remove the old upgrade jobs.
+			// Example: https://prow.k8s.io/view/gs/kubernetes-jenkins/logs/e2e-kops-aws-upgrade-k125-ko128-to-k126-kolatest/1808210907088556032
+			skipRegex += "|\\[Driver:.aws\\].\\[Testpattern:.Pre-provisioned.PV|\\[Driver:.aws\\].\\[Testpattern:.Inline-volume"
+		}
+	}
+
+	// This test fails on RHEL-based distros because they return fully qualified hostnames yet the k8s node names are not fully qualified.
+	// Dedicated job testing this: https://testgrid.k8s.io/kops-misc#kops-aws-k28-hostname-bug123255
+	// ref: https://github.com/kubernetes/kops/issues/16349
+	// ref: https://github.com/kubernetes/kubernetes/issues/123255
+	// ref: https://github.com/kubernetes/kubernetes/issues/121018
+	// < 33 so we look at this again
+	if k8sVersion.Minor < 33 {
 		skipRegex += "|Services.should.function.for.service.endpoints.using.hostNetwork"
 	}
 
