@@ -25,7 +25,6 @@ import (
 	"k8s.io/klog/v2"
 
 	kopsapi "k8s.io/kops/pkg/apis/kops"
-	"k8s.io/kops/pkg/apis/kops/util"
 	"k8s.io/kops/pkg/apis/kops/validation"
 	"k8s.io/kops/pkg/assets"
 	"k8s.io/kops/pkg/client/simple"
@@ -295,18 +294,13 @@ func (c *populateClusterSpec) run(ctx context.Context, clientset simple.Clientse
 	if cluster.Spec.KubernetesVersion == "" {
 		return fmt.Errorf("KubernetesVersion is required")
 	}
-	sv, err := util.ParseKubernetesVersion(cluster.Spec.KubernetesVersion)
+
+	optionsContext, err := components.NewOptionsContext(cluster, c.assetBuilder, c.assetBuilder.KubeletSupportedVersion)
 	if err != nil {
-		return fmt.Errorf("unable to determine kubernetes version from %q", cluster.Spec.KubernetesVersion)
+		return err
 	}
 
-	optionsContext := &components.OptionsContext{
-		ClusterName:       cluster.ObjectMeta.Name,
-		KubernetesVersion: *sv,
-		AssetBuilder:      c.assetBuilder,
-	}
-
-	var codeModels []loader.OptionsBuilder
+	var codeModels []loader.ClusterOptionsBuilder
 	{
 		{
 			// Note: DefaultOptionsBuilder comes first
@@ -340,27 +334,23 @@ func (c *populateClusterSpec) run(ctx context.Context, clientset simple.Clientse
 	}
 
 	specBuilder := &SpecBuilder{
-		OptionsLoader: loader.NewOptionsLoader(codeModels),
+		OptionsLoader: loader.NewClusterOptionsLoader(codeModels),
 	}
 
-	completed, err := specBuilder.BuildCompleteSpec(&cluster.Spec)
+	completed, err := specBuilder.BuildCompleteSpec(cluster)
 	if err != nil {
 		return fmt.Errorf("error building complete spec: %v", err)
 	}
 
 	// TODO: This should not be needed...
-	completed.Networking.Topology = c.InputCluster.Spec.Networking.Topology
+	completed.Spec.Networking.Topology = c.InputCluster.Spec.Networking.Topology
 	// completed.Topology.Bastion = c.InputCluster.Spec.Topology.Bastion
 
-	fullCluster := &kopsapi.Cluster{}
-	*fullCluster = *cluster
-	fullCluster.Spec = *completed
-
-	if errs := validation.ValidateCluster(fullCluster, true, clientset.VFSContext()); len(errs) != 0 {
+	if errs := validation.ValidateCluster(completed, true, clientset.VFSContext()); len(errs) != 0 {
 		return fmt.Errorf("completed cluster failed validation: %v", errs.ToAggregate())
 	}
 
-	c.fullCluster = fullCluster
+	c.fullCluster = completed
 	return nil
 }
 
